vfbLib.parsers.glyph.GlyphUnicodeSuppParser
===========================================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: GlyphUnicodeSuppParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphUnicodeSuppParser.__init__
      ~GlyphUnicodeSuppParser.parse
      ~GlyphUnicodeSuppParser.parse_hex
      ~GlyphUnicodeSuppParser.read_double
      ~GlyphUnicodeSuppParser.read_doubles
      ~GlyphUnicodeSuppParser.read_float
      ~GlyphUnicodeSuppParser.read_floats
      ~GlyphUnicodeSuppParser.read_int16
      ~GlyphUnicodeSuppParser.read_int32
      ~GlyphUnicodeSuppParser.read_int8
      ~GlyphUnicodeSuppParser.read_str
      ~GlyphUnicodeSuppParser.read_str_all
      ~GlyphUnicodeSuppParser.read_uint16
      ~GlyphUnicodeSuppParser.read_uint32
      ~GlyphUnicodeSuppParser.read_uint8
      ~GlyphUnicodeSuppParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphUnicodeSuppParser.encoding
      ~GlyphUnicodeSuppParser.master_count
      ~GlyphUnicodeSuppParser.stream
      ~GlyphUnicodeSuppParser.ttStemsH_count
      ~GlyphUnicodeSuppParser.ttStemsV_count
   
   